@@ -1,4 +1,12 @@
-"Main interface for acm-pca service type defs"
+"""
+Main interface for acm-pca service type definitions.
+
+Usage::
+
+    from mypy_boto3.acm_pca.type_defs import ASN1SubjectTypeDef
+
+    data: ASN1SubjectTypeDef = {...}
+"""
 from datetime import datetime
 import sys
 from typing import List
@@ -13,6 +21,30 @@ else:
     from typing_extensions import TypedDict
 
 
+__all__ = (
+    "ASN1SubjectTypeDef",
+    "CertificateAuthorityConfigurationTypeDef",
+    "CreateCertificateAuthorityAuditReportResponseTypeDef",
+    "CreateCertificateAuthorityResponseTypeDef",
+    "DescribeCertificateAuthorityAuditReportResponseTypeDef",
+    "CrlConfigurationTypeDef",
+    "RevocationConfigurationTypeDef",
+    "CertificateAuthorityTypeDef",
+    "DescribeCertificateAuthorityResponseTypeDef",
+    "GetCertificateAuthorityCertificateResponseTypeDef",
+    "GetCertificateAuthorityCsrResponseTypeDef",
+    "GetCertificateResponseTypeDef",
+    "IssueCertificateResponseTypeDef",
+    "ListCertificateAuthoritiesResponseTypeDef",
+    "PermissionTypeDef",
+    "ListPermissionsResponseTypeDef",
+    "TagTypeDef",
+    "ListTagsResponseTypeDef",
+    "PaginatorConfigTypeDef",
+    "ValidityTypeDef",
+    "WaiterConfigTypeDef",
+)
+
 ASN1SubjectTypeDef = TypedDict(
     "ASN1SubjectTypeDef",
     {
